@@ -1,4 +1,4 @@
-use fltk::{app, enums::Event, prelude::*, window};
+use fltk::{app, prelude::*, window};
 
 fn main() {
     let _app = app::App::default();
@@ -9,15 +9,9 @@ fn main() {
         .with_size(790, 590)
         .center_of_parent();
     win.end();
+    win.make_resizable(true);
     win.show();
 
-    // close the app when the main window is closed
-    win.set_callback(|_| {
-        if app::event() == Event::Close {
-            std::process::exit(0);
-        }
-    });
-
     let mut wv = fltk_webview::Webview::create(false, &mut wv_win);
     wv.navigate("https://google.com");
     
